spread

Function spread 

fn spread(scan: &mut Scan, index: usize) -> bool
Check the neighboring horizontal tile first to see if we can keep spreading, then check the tile underneath. Speed things up by first checking via the middle condition if the tile is already stopped water or clay.